@@ -2,6 +2,7 @@
 #' The purpose of this multiplier is to lessen the risk stemming from the addons in case of excess collateral
 #' @title Calculates the PFE
 #' @param V_C the difference between the sum of the MtMs and the collateral
+#' @param V the sum of MVs of the trades
 #' @param Addon_Aggregate the aggregate amount of the Addon
 #' @param simplified (optional) When TRUE, the multiplier will be set to 1  as per the simplified & OEM approach
 #' @return The Projected Future Exposure (PFE)
@@ -10,8 +11,11 @@
 #' @references Regulation (EU) 2019/876 of the European Parliament and of the Council of 20 May 2019
 #' http://data.europa.eu/eli/reg/2019/876/oj
 
-CalcPFE <- function(V_C,Addon_Aggregate, simplified)  {
+CalcPFE <- function(V_C,Addon_Aggregate, simplified,V=0)  {
   
+  if(missing(V)) V=V_C
+  
+  V_C= min(V_C,V)
   if(simplified)
   {  multiplier = 1
   }else
